﻿/* ========================================================================== */
/*!
 * 
 */
/* ========================================================================== */
using System;
using System.Collections;
using System.Collections.Generic;
using System.Diagnostics;
using System.Windows.Forms;
using System.Text;
using System.IO;

namespace RecTestSched
{
    public class General
    {
        //!
        static private Hashtable myRecorder = null;
        //!
        static internal bool myExceptionExit;

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public Hashtable GetRecorderTable()
        {
            if (myRecorder == null)
            {
                myRecorder = new Hashtable();
            }
            return myRecorder;
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public void DelRecorderTable()
        {
            if (myRecorder != null)
            {
                myRecorder.Clear();
                myRecorder = null;
            }
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public void OnExit()
        {
            if (myRecorder != null)
            {
                foreach (RecorderMain recMain in myRecorder)
                {
                    recMain.OnExit();
                }
            }
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public void OutputString( string _stack
                                       , string _str
                                       )
        {
        #if DEBUG
            Debug.Listeners.Add(new TextWriterTraceListener(Console.Out));
            Debug.WriteLine( "> "
                            + _str
                            + Environment.NewLine
                            + _stack
                            );
        #endif
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public void LogOut( int _level
                                 , string _str
                                 )
        {
            if (!ScheduleForm.GetInstance().CheckLogLevel())
            {
                if (_level > 1) { return; }
            }
            if (RecTestSched.GetInstance() != null)
            {
                RecTestSched.GetInstance().LogOut(_str);
            }
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public void TimerPause(System.Threading.Timer _timer)
        {
            if (_timer != null)
            {
                _timer.Change(System.Threading.Timeout.Infinite, System.Threading.Timeout.Infinite);
            }
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public ProcessPriorityClass ProcessPriority(string _prio)
        {
            switch (_prio)
            {
                case "Idle"     : return ProcessPriorityClass.Idle;
                case "High"     : return ProcessPriorityClass.High;
                case "RealTime" : return ProcessPriorityClass.RealTime;
                case "Normal"   : return ProcessPriorityClass.Normal;
            }
            return ProcessPriorityClass.Normal;
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public DateTime PureTime(DateTime _time)
        {
            _time = _time.AddMilliseconds(1000 - _time.Millisecond);
            _time = _time.AddSeconds(60 - _time.Second);
            return _time;
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public int ToInt32(Object _obj)
        {
            int result = 0;
            try
            {
                result = Convert.ToInt32(_obj);
            }
            catch (Exception exp)
            {
                result = 0;
                General.OutputString(exp.StackTrace, exp.Message);
            }
            return result;
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public bool IsInt32(Object _obj)
        {
            bool beInt = true;
            try
            {
                int result = Convert.ToInt32(_obj);
            }
            catch (Exception exp)
            {
                beInt = false;
                General.OutputString(exp.StackTrace, exp.Message);
            }
            return beInt;
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public DateTime ToDateTime(Object _obj)
        {
            DateTime result;
            try
            {
                result = Convert.ToDateTime(_obj);
            }
            catch (Exception exp)
            {
                result = DateTime.Now.AddMinutes(5);
                General.OutputString(exp.StackTrace, exp.Message);
            }
            return result;
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public string ToString( DataGridViewCellCollection _cell
                                     , DataGridViewTextBoxColumn _column
                                     )
        {
            string result = "";
            try
            {
                if (_cell[_column.Index].Value == null) { return ""; }
                result = Convert.ToString(_cell[_column.Index].Value);
            }
            catch (Exception exp)
            {
                result = "";
                General.OutputString(exp.StackTrace, exp.Message);
            }
            return result;
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public int ToInt32( DataGridViewCellCollection _cell
                                 , DataGridViewTextBoxColumn _column
                                 )
        {
            int result = 0;
            try
            {
                if (_cell[_column.Index].Value == null) { return 0; }
                result = Convert.ToInt32(_cell[_column.Index].Value);
            }
            catch (Exception exp)
            {
                result = 0;
                General.OutputString(exp.StackTrace, exp.Message);
            }
            return result;
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public DateTime ToDateTime( DataGridViewCellCollection _cell
                                          , DataGridViewTextBoxColumn _column
                                          )
        {
            DateTime result = DateTime.Now;
            try
            {
                if (_cell[_column.Index].Value == null) { return result; }
                result = Convert.ToDateTime(_cell[_column.Index].Value);
            }
            catch (Exception exp)
            {
                General.OutputString(exp.StackTrace, exp.Message);
            }
            return result;
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public string ToString(byte[] _byte)
        {
            string result = "";
            try
            {
                StringBuilder builder = new StringBuilder();
                foreach (byte b in _byte)
                {
                    builder.Append(b.ToString("x2"));
                }
                result = builder.ToString();
            }
            catch (Exception exp)
            {
                General.OutputString(exp.StackTrace, exp.Message);
            }
            return result;
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public string ToMd5(string _base)
        {
            try
            {
                byte[] data = Encoding.ASCII.GetBytes(_base);
                System.Security.Cryptography.MD5 md5 = System.Security.Cryptography.MD5.Create();
                byte[] md5byte = md5.ComputeHash(data);
                return ToString(md5byte);
            }
            catch (Exception exp)
            {
                General.OutputString(exp.StackTrace, exp.Message);
            }
            return "";
        }

        /* ========================================================================== */
        /*!
         */
        /* ========================================================================== */
        static public bool Move( string _old
                               , string _new
                               , string _name
                               )
        {
            try
            {
                string oldConfig = Path.Combine(_old, _name);
                if (File.Exists(oldConfig))
                {
                    string newConfig = Path.Combine(_new, _name);
                    if (File.Exists(newConfig))
                    {
                        DateTime oldStamp = File.GetLastAccessTime(oldConfig);
                        DateTime newStamp = File.GetLastAccessTime(newConfig);
                        if (oldStamp > newStamp)
                        {
                            File.Move(oldConfig, newConfig);
                        }
                        else
                        {
                            File.Delete(oldConfig);
                        }
                    }
                    else
                    {
                        File.Move(oldConfig, newConfig);
                    }
                    try
                    {
                        if (File.Exists(oldConfig))
                        {
                            File.Delete(oldConfig);
                        }
                    }
                    catch (Exception exp)
                    {
                        General.OutputString(exp.StackTrace, exp.Message);
                    }
                    return true;
                }
            }
            catch (Exception exp)
            {
                General.OutputString(exp.StackTrace, exp.Message);
            }
            return false;
        }

    }
}

